@@ -25,16 +25,13 @@ class RowGenerator(metaclass=ABCMeta):
         self._row = self.rounds()
 
     def is_tower_size_valid(self, tower_size) -> bool:
-        """
-        Returns True if the row_generator can generate rows correctly for a given tower size.
-        """
-
+        """ Returns True if the row_generator can generate rows correctly for a given tower size. """
         return tower_size == self.number_of_bells
 
     def reset(self):
         """ Reset the row generator. """
-
         self.logger.info("Reset")
+
         self._has_bob = False
         self._has_single = False
         self._index = 0
@@ -42,14 +39,13 @@ class RowGenerator(metaclass=ABCMeta):
 
     def reset_calls(self):
         """ Clear the pending call flags. """
-
         self.logger.info("Reset calls")
+
         self._has_bob = False
         self._has_single = False
 
     def next_row(self, is_handstroke: bool) -> List[Bell]:
         """ Generate the next row, and mutate state accordingly. """
-
         self._row = self._gen_row(self._row, is_handstroke, self._index)
         self._add_cover_if_required()
 
@@ -62,17 +58,14 @@ class RowGenerator(metaclass=ABCMeta):
 
     def set_bob(self):
         """ Set the flag that a bob has been made. """
-
         self._has_bob = True
 
     def set_single(self):
         """ Set the flag that a single has been made. """
-
         self._has_single = True
 
     def rounds(self) -> List[Bell]:
         """ Generate rounds of the stage given by this RowGenerator. """
-
         return [Bell.from_number(i) for i in range(1, self.number_of_bells + 1)]
 
     def _add_cover_if_required(self):
@@ -85,8 +78,8 @@ class RowGenerator(metaclass=ABCMeta):
 
     def permute(self, row: List[Bell], places: List[int]) -> List[Bell]:
         """ Permute a row by a place notation given by `places`. """
-
         new_row = list(row)
+
         i = 1
         if places and places[0] % 2 == 0:
             # Skip 1 for implicit lead when lowest pn is even
@@ -96,9 +89,9 @@ class RowGenerator(metaclass=ABCMeta):
             if i in places:
                 i += 1
                 continue
-            else:
-                # If not in place, must swap, index is 1 less than place
-                new_row[i - 1], new_row[i] = new_row[i], new_row[i - 1]
-                i += 2
+
+            # If not in place, must swap, index is 1 less than place
+            new_row[i - 1], new_row[i] = new_row[i], new_row[i - 1]
+            i += 2
 
         return new_row
